##  Publishing and Unpublishing Templates from the Overview Page
If you don’t publish directly in the editor, you can publish or unpublish a template from the diagram templates page:
  1. Go to the Diagram Templates page.
  2. Find the template you want to change.
  3. Open the More actions (…) menu next to the template.
  4. Select Diagram Details.
  5. Use the Workspace Visibility drop-down list to:
     * Publish: Everyone in the workspace can see and use the template (subject to their diagram template permissions).
     * Unpublish: Hides the template from workspace users. Only users with explicit view permissions can access it.


YesNo
Send
